Learn R Programming

hierfstat (version 0.04-22)

eucl.dist: Estimates euclidian distances

Description

Estimates euclidian distances among pairs of samples from a gnetic data set

Usage

eucl.dist(data,allloc=FALSE,distance="eucl")

Arguments

data

a genetic data set, such as obtained from read.fstat

allloc

whether to print out the distance for each locus

distance

not used yet. Goal is to have only one distance function

Value

either a matrix [np*(np-1)/2,nl] or a vector [np*(np-1)/2] of genetic distances among pairs 2-1, 3-1, 3-2,4-1,etc

Examples

Run this code
# NOT RUN {
data(gtrunchier)
eucl.dist(gtrunchier[,-1])
# }

Run the code above in your browser using DataLab