powered by
calculates euclidian distance among populations for a trait
eucl.dist.trait(data)
a 2 columns data frame, the first columen identifying the population of origin, the second teh value for the trait
a vector of euclidian distances 2-1, 3-1, 3-2 etc