powered by
Read QuantiNemo (http://www2.unil.ch/popgen/softwares/quantinemo/) genotype files extended format (option 2)
qn2.read.fstat(fname, na.s = c("NA","NaN"))
quantinemo file name
na string used
dat a data frame with nloc+1 columns, the first being the population to which the individual belongs and the next being the genotypes, one column per locus; and ninds rows
sex the sex of the individuals
Neuenschwander S, Hospital F, Guillaume F, Goudet J (2008) quantiNEMO: an individual-based program to simulate quantitative traits with explicit genetic architecture in a dynamic metapopulation Bioinformatics 24, 1552-1553.
read.fstat
# NOT RUN { dat<-qn2.read.fstat(system.file("extdata","qn2_sex.dat",package="hierfstat")) sexbias.test(dat[[1]],sex=dat[[2]]) # }
Run the code above in your browser using DataLab