powered by
Estimates euclidian distances among pairs of samples from a gnetic data set
eucl.dist(data,allloc=FALSE,distance="eucl")
a genetic data set, such as obtained from read.fstat
whether to print out the distance for each locus
not used yet. Goal is to have only one distance function
either a matrix [np*(np-1)/2,nl] or a vector [np*(np-1)/2] of genetic distances among pairs 2-1, 3-1, 3-2,4-1,etc
# NOT RUN { data(gtrunchier) eucl.dist(gtrunchier[,-1]) # }
Run the code above in your browser using DataLab